@@ -15,9 +15,8 @@ package Lingua::Align::Features::Lexical;
 use 5.005;
 use strict;
 
-use vars qw($VERSION @ISA);
+use vars qw(@ISA);
 @ISA = qw(Lingua::Align::Features::Tree);
-$VERSION = '0.01';
 
 
 sub get_features{
@@ -842,26 +841,3 @@ sub unionscoreXY{
 
 
 1;
-__END__
-
-=head1 NAME
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-=head1 SEE ALSO
-
-=head1 AUTHOR
-
-Joerg Tiedemann, E<lt>j.tiedemann@rug.nlE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2009 by Joerg Tiedemann
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-=cut
