@@ -24,9 +24,8 @@ package Lingua::Align::Trees;
 use 5.005;
 use strict;
 
-use vars qw($VERSION @ISA);
+use vars qw(@ISA);
 @ISA = qw(Lingua::Align);
-$VERSION = '0.02';
 
 use FileHandle;
 use Time::HiRes qw ( time alarm sleep );
